% DesignControllerAndObserver.m (script)
%
% Script to design the centralized state observer (5), (6), and the
% state-feedback controller (7).
%
% --
% Supplementary material to:
% Sebastian Trimpe, "Stability Analysis of Distributed Event-Based State
% Estimation", IEEE Conference on Decision and Control (CDC), 2014.
%
% Copyright:
% Sebastian Trimpe
% Max-Planck-Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%

% Revision history
% [21.03.14]   preliminary version, published with initial submission
% [13.09.14]   Working with TSS plant, update for final submission


%% Load linear model
load DiscreteTimeLinearModel.mat;


%% State-feedback controller: LQR design
% Weight matrices
R = 0.1*eye(2);
Q = diag([1 0 1 0 1 1]);

% Discrete time LQR design.
[F,S,e] = dlqr(linMod_sim.A,linMod_sim.B,Q,R,[]);

% Controller gain:
F = -F;     % positive feedback


%% State observer: Steady-state Kalman filter
% Weight matrices
Rn = eye(3);                        % measurement noise
Qn = 0.1*diag([1 1 0.001 0.001]);   % process noise

% Solve DARE:
P = dare(linMod_est.A',linMod_est.C',Qn,Rn)';

% Observer gain:
L = P*linMod_est.C'*inv(linMod_est.C*P*linMod_est.C'+Rn);
